@@ -1,17 +1,20 @@
 """Misc validators for things like emails, domains, etc."""
 import re
-import socket
 
+import dns
 import dns.resolver
 
+from ocflib.infra.net import OCF_DNS_RESOLVER
+
 
 def host_exists(host):
     try:
-        host_info = socket.getaddrinfo(host, None)
-    except socket.gaierror:
+        message = dns.message.make_query(host, dns.rdatatype.ANY)
+    except dns.name.EmptyLabel:
         return False
-    else:
-        return bool(host_info)
+
+    response = dns.query.udp(message, str(OCF_DNS_RESOLVER))
+    return bool(response.answer)
 
 
 def email_host_exists(email_addr):
@@ -25,9 +28,9 @@ def email_host_exists(email_addr):
 def valid_email(email):
     """Check the email with naive regex and check for the domain's MX record.
     Returns True for valid email, False for bad email."""
-    regex = r'^[a-zA-Z0-9._%\-+]+@([a-zA-Z0-9._%\-]+.[a-zA-Z]{2,6})$'
+    regex = r'^[a-z0-9._%\-+]+@([a-z0-9._%\-]+.[a-z]{2,})$'
 
-    m = re.match(regex, email)
+    m = re.match(regex, email, re.IGNORECASE)
     if m:
         domain = m.group(1)
         try:
