@@ -1,13 +1,15 @@
-import os.path
 from contextlib import contextmanager
 from textwrap import dedent
 
 import mock
 import pytest
+from Crypto.PublicKey import RSA
+from freezegun import freeze_time
 from sqlalchemy import create_engine
 from sqlalchemy.orm import sessionmaker
 
-import ocflib.account.creation
+import ocflib.constants as constants
+from ocflib.account.creation import _cache
 from ocflib.account.creation import _get_first_available_uid
 from ocflib.account.creation import create_account
 from ocflib.account.creation import create_home_dir
@@ -28,6 +30,7 @@ from ocflib.account.creation import ValidationError
 from ocflib.account.creation import ValidationWarning
 from ocflib.account.submission import AccountCreationCredentials
 from ocflib.account.submission import Base
+from ocflib.infra.ldap import ldap_ocf
 
 WEAK_KEY = dedent(
     """\
@@ -65,7 +68,7 @@ def fake_new_account_request(mock_rsa_key):
         calnet_uid=123456,
         callink_oid=None,
         email='some.user@ocf.berkeley.edu',
-        encrypted_password=encrypt_password('hunter2000', mock_rsa_key),
+        encrypted_password=encrypt_password('hunter2000', RSA.importKey(WEAK_KEY)),
         handle_warnings=NewAccountRequest.WARNINGS_WARN,
     )
 
@@ -80,8 +83,7 @@ def mock_rsa_key(tmpdir):
 
 class TestFirstAvailableUID:
 
-    @mock.patch('ocflib.account.creation.send_problem_report')
-    def test_first_uid(self, send_problem_report):
+    def test_first_uid(self):
         connection = mock.Mock(response=[
             {'attributes': {'uidNumber': [999000]}},
             {'attributes': {'uidNumber': [999200]}},
@@ -96,24 +98,32 @@ class TestFirstAvailableUID:
             next_uid = _get_first_available_uid()
 
         assert next_uid == 999201
-        assert not send_problem_report.called
 
-    @mock.patch('ocflib.account.creation.send_problem_report')
-    def test_alerts_staff_if_too_many(self, send_problem_report):
-        connection = mock.Mock(response=[
-            {'attributes': {'uidNumber': [n]}}
-            for n in range(100000, 100000 + 5000)
-        ])
+    def test_max_uid_constant_not_too_small(self):
+        """Test that the known_min constant is sufficiently large.
 
-        @contextmanager
-        def ldap_ocf():
-            yield connection
+        The way we find the next available UID is very slow because there is no
+        way to do a query like "find the max UID from all users" in LDAP.
+        We instead have to find all users and take the max ourselves. This can
+        take ~15 seconds.
 
-        with mock.patch('ocflib.account.creation.ldap_ocf', ldap_ocf):
-            next_uid = _get_first_available_uid()
+        By hardcoding a known min, we just select accounts with uid >
+        known_min, which is much faster. But it means we need to bump the
+        constant occasionally to keep it fast.
+        """
+        known_uid = _cache['known_uid']
+        with ldap_ocf() as c:
+            c.search(
+                constants.OCF_LDAP_PEOPLE,
+                '(uidNumber>={KNOWN_MIN})'.format(KNOWN_MIN=known_uid),
+                attributes=['uidNumber'],
+            )
+            num_uids = len(c.response)
 
-        assert next_uid == 105000
-        assert send_problem_report.called
+        if num_uids > 2500:
+            raise AssertionError((
+                'Found {} accounts with UID >= {}, you should bump the constant for speed.'
+            ).format(num_uids, known_uid))
 
 
 class TestCreateDirectories:
@@ -127,26 +137,21 @@ class TestCreateDirectories:
                 '--owner=ckuehl', '/home/c/ck/ckuehl'],
         )]
 
-        for name in ['bashrc', 'bash_profile', 'bash_logout']:
-            path = os.path.join(os.path.dirname(
-                ocflib.account.creation.__file__),
-                'rc',
-                name,
-            )
-            calls.append(mock.call(
-                ['sudo', 'install', '--mode=0600', '--group=ocf',
-                    '--owner=ckuehl', path, '/home/c/ck/ckuehl/.' + name],
-            ))
-
         check_call.assert_has_calls(calls)
 
     @mock.patch('subprocess.check_call')
     def test_create_web_dir(self, check_call):
         create_web_dir('ckuehl')
-        check_call.assert_called_with(
-            ['sudo', 'install', '-d', '--mode=0000', '--group=ocf',
-                '--owner=ckuehl', '/services/http/users/c/ckuehl'],
-        )
+        check_call.assert_has_calls([
+            mock.call([
+                'sudo', 'install', '-d', '--mode=0755', '--group=ocf', '--owner=ckuehl',
+                '--', '/services/http/users/c/ckuehl',
+            ]),
+            mock.call([
+                'sudo', '-u', 'ckuehl', 'ln', '-fs', '--',
+                '/services/http/users/c/ckuehl', '/home/c/ck/ckuehl/public_html',
+            ]),
+        ])
 
 
 class TestUsernameBasedOnRealName:
@@ -175,7 +180,6 @@ class TestUsernameBasedOnRealName:
 
     @pytest.mark.parametrize('username', [
         'shitup',
-        'hella',
         'ucbcop',
         'suxocf',
     ])
@@ -247,7 +251,9 @@ class TestAccountEligibility:
         (['EMPLOYEE-STATUS-EXPIRED', 'STUDENT-TYPE-REGISTERED'], True),
 
         (['STUDENT-TYPE-REGISTERED'], True),
+        (['STUDENT-TYPE-NOT REGISTERED'], True),
         (['STUDENT-TYPE-REGISTERED', 'STUDENT-STATUS-EXPIRED'], False),
+        (['STUDENT-TYPE-NOT REGISTERED', 'STUDENT-STATUS-EXPIRED'], False),
         (['STUDENT-STATUS-EXPIRED'], False),
 
         ([], False),
@@ -286,8 +292,8 @@ class TestPasswordEncryption:
     ])
     def test_encrypt_decrypt_password(self, password, mock_rsa_key):
         assert decrypt_password(
-            encrypt_password(password, mock_rsa_key),
-            mock_rsa_key,
+            encrypt_password(password, RSA.importKey(WEAK_KEY)),
+            RSA.importKey(WEAK_KEY),
         ) == password
 
 
@@ -475,7 +481,9 @@ class TestCreateAccount:
                 mock.patch('ocflib.account.creation.create_home_dir') as home_dir, \
                 mock.patch('ocflib.account.creation.create_web_dir') as web_dir, \
                 mock.patch('ocflib.account.creation.send_created_mail') as send_created_mail, \
-                mock.patch('ocflib.account.creation._get_first_available_uid', return_value=42):
+                mock.patch('ocflib.account.creation._get_first_available_uid', return_value=42), \
+                mock.patch('ocflib.account.creation.call') as call, \
+                freeze_time('2015-08-22 14:11:44'):
 
             fake_new_account_request = fake_new_account_request._replace(
                 is_group=is_group,
@@ -504,10 +512,12 @@ class TestCreateAccount:
                     'loginShell': ['/bin/bash'],
                     'mail': ['some.user@ocf.berkeley.edu'],
                     'userPassword': ['{SASL}someuser@OCF.BERKELEY.EDU'],
+                    'creationTime': ['20150822141144Z'],
                 }, **expected),
                 fake_credentials.kerberos_keytab,
                 fake_credentials.kerberos_principal,
             )
+            call.assert_called_once_with(('sudo', 'nscd', '-i', 'passwd'))
             home_dir.assert_called_once_with(fake_new_account_request.user_name)
             web_dir.assert_called_once_with(fake_new_account_request.user_name)
             send_created_mail.assert_called_once_with(fake_new_account_request)
